@@ -65,9 +65,10 @@ class ExecutableSerialisation:
         self.capture = capture
 
 class TestSerialisation:
-    def __init__(self, name, suite, fname, is_cross_built, exe_wrapper, is_parallel, cmd_args, env,
-                 should_fail, timeout, workdir, extra_paths):
+    def __init__(self, name, project, suite, fname, is_cross_built, exe_wrapper, is_parallel,
+                 cmd_args, env, should_fail, timeout, workdir, extra_paths):
         self.name = name
+        self.project_name = project
         self.suite = suite
         self.fname = fname
         self.is_cross_built = is_cross_built
@@ -312,7 +313,7 @@ class Backend:
     def rpaths_for_bundled_shared_libraries(self, target):
         paths = []
         for dep in target.external_deps:
-            if isinstance(dep, dependencies.ExternalLibrary):
+            if isinstance(dep, (dependencies.ExternalLibrary, dependencies.PkgConfigDependency)):
                 la = dep.link_args
                 if len(la) == 1 and os.path.isabs(la[0]):
                     # The only link argument is an absolute path to a library file.
@@ -322,7 +323,7 @@ class Backend:
                         continue
                     if os.path.splitext(libpath)[1] not in ['.dll', '.lib', '.so']:
                         continue
-                    absdir = os.path.split(libpath)[0]
+                    absdir = os.path.dirname(libpath)
                     if absdir.startswith(self.environment.get_source_dir()):
                         rel_to_src = absdir[len(self.environment.get_source_dir()) + 1:]
                         assert not os.path.isabs(rel_to_src), 'rel_to_src: {} is absolute'.format(rel_to_src)
@@ -349,6 +350,11 @@ class Backend:
         assert isinstance(source, mesonlib.File)
         build_dir = self.environment.get_build_dir()
         rel_src = source.rel_to_builddir(self.build_to_src)
+
+        if (not self.environment.is_source(rel_src) or
+           self.environment.is_header(rel_src)) and not is_unity:
+            return None
+
         # foo.vala files compile down to foo.c and then foo.c.o, not foo.vala.o
         if rel_src.endswith(('.vala', '.gs')):
             # See description in generate_vala_compile for this logic.
@@ -396,24 +402,19 @@ class Backend:
             return [objpath]
         for osrc in extobj.srclist:
             objname = self.object_filename_from_source(extobj.target, osrc, False)
-            objpath = os.path.join(proj_dir_to_build_root, targetdir, objname)
-            result.append(objpath)
+            if objname:
+                objpath = os.path.join(proj_dir_to_build_root, targetdir, objname)
+                result.append(objpath)
         return result
 
     def get_pch_include_args(self, compiler, target):
         args = []
         pchpath = self.get_target_private_dir(target)
         includeargs = compiler.get_include_args(pchpath, False)
-        for lang in ['c', 'cpp']:
-            p = target.get_pch(lang)
-            if not p:
-                continue
-            if compiler.can_compile(p[-1]):
-                header = p[0]
-                args += compiler.get_pch_use_args(pchpath, header)
-        if len(args) > 0:
-            args = includeargs + args
-        return args
+        p = target.get_pch(compiler.get_language())
+        if p:
+            args += compiler.get_pch_use_args(pchpath, p[0])
+        return includeargs + args
 
     @staticmethod
     def escape_extra_args(compiler, args):
@@ -603,9 +604,9 @@ class Backend:
                     cmd_args.append(self.get_target_filename(a))
                 else:
                     raise MesonException('Bad object in test command.')
-            ts = TestSerialisation(t.get_name(), t.suite, cmd, is_cross, exe_wrapper,
-                                   t.is_parallel, cmd_args, t.env, t.should_fail,
-                                   t.timeout, t.workdir, extra_paths)
+            ts = TestSerialisation(t.get_name(), t.project_name, t.suite, cmd, is_cross,
+                                   exe_wrapper, t.is_parallel, cmd_args, t.env,
+                                   t.should_fail, t.timeout, t.workdir, extra_paths)
             arr.append(ts)
         pickle.dump(arr, datafile)
 
